package com.goldenwater.slgc.mapper;

import java.util.List;
import com.goldenwater.slgc.domain.SlgcWaterUnitRecord;
import org.apache.ibatis.annotations.Mapper;

/** 审核记录 Mapper */
@Mapper
public interface SlgcWaterUnitRecordMapper {
    /**
     * 查询审核记录列表
     *
     * @param unitId 水管单位ID
     * @return 审核记录列表
     */
    public List<SlgcWaterUnitRecord> selectSlgcWaterUnitRecordList(String unitId);

    /**
     * 通过ID查询审核记录
     *
     * @param id 主键ID
     * @return 审核记录
     */
    public SlgcWaterUnitRecord selectSlgcWaterUnitRecordById(String id);

    /**
     * 新增审核记录
     *
     * @param record 审核记录
     * @return 影响行数
     */
    public int insertSlgcWaterUnitRecord(SlgcWaterUnitRecord record);

    /**
     * 修改审核记录
     *
     * @param record 审核记录
     * @return 影响行数
     */
    public int updateSlgcWaterUnitRecord(SlgcWaterUnitRecord record);

    /**
     * 批量删除审核记录
     *
     * @param ids 主键ID数组
     * @return 影响行数
     */
    public int deleteSlgcWaterUnitRecordByIds(String[] ids);

    /**
     * 查询最大ID
     *
     * @return 最大ID
     */
    public Integer findMaxId();
}
